=======
Shadocs
=======


.. image:: https://img.shields.io/pypi/v/shadocs.svg
        :target: https://pypi.python.org/pypi/shadocs

.. image:: https://img.shields.io/travis/llango/shadocs.svg
        :target: https://travis-ci.com/llango/shadocs

.. image:: https://readthedocs.org/projects/shadocs/badge/?version=latest
        :target: https://shadocs.readthedocs.io/en/latest/?version=latest
        :alt: 文档状态




Shadocs 一个清新美丽的mkdocs 主题。


* 开源协议: MIT license
* 文档: https://shadocs.readthedocs.io.


特征
--------

* ` pip install shadocs ` 进行安装便可。
*  修改mkdocs.yml 文件theme: name: 设置为 shadocs 便可。

鸣谢
-------

该包使用了 Cookiecutter_ 和 `llango/cookiecutter-shapackage`_ 模板创建。

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`llango/cookiecutter-shapackage`: https://github.com/llango/cookiecutter-shapackage

效果图
--------

.. image:: ./screen/jietu.png
        :alt: 主题效果图